#import <objectbase.h>
#import "Forest.h"

@interface YoungForest: Forest {
  id forest ;
}

-setForest: aForest ;
-graduateTree: aTree ;
@end
